import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleTime, timeFormat, extent } from 'd3';
import { load } from './load';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

// Declaring width, height and margin
const width = 960;
const height = 500;
const margin = {
  top: 30,
  right: 20,
  bottom: 60,
  left: 160,
};

// Declaring xAxis and yAxis labels
const xAxisLabelOffset = 45;
const yAxisLabelOffset = 85;
const xValue = (d) => d.year;
const xAxisLabel = 'Year';
const yValue = (d) => d.population;
const yAxisLabel = 'Average Population in US';
const xAxisTickFormat = timeFormat("%Y");


// Running application
const App = () => {
  const data = load();

  // Preview loading data while loading it 
  if (!data) {
    return <pre>Loading data...</pre>;
  }
	
  console.log(data[0]);
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
  // Defining xscale and yscale for the line chart
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  	.nice();

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={7}
        />
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
        />
				<Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={3}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
          tickOffset={7}
        >
          {xAxisLabel}
        </text>
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight / 2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
